@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1991,1992 Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Copyright (C) 1991-1999 Erik Schoenfelder (schoenfr@web.de)
  *
  * This file is part of NASE A60.
  * 
@@ -19,7 +19,7 @@
  *
  * a60-scan.c:						oct '90
  *
- * Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Erik Schoenfelder (schoenfr@web.de)
  *
  * The Algol 60 scanner.
  *
@@ -125,6 +125,8 @@ int len;
 	return buf;
 }
 
+
+#ifdef DEBUG
 /*
  * return a printable string for a single char:
  */
@@ -139,6 +141,7 @@ int ch;
 
 	return asc_str (tmp, 1);
 }
+#endif
 
 
 /*
@@ -380,8 +383,8 @@ int n;
  * return 10 power n:
  */
 
-double
-pow10 (n)
+static double
+my_pow10 (n)
 int n;
 {
 	int rev = 0;
@@ -894,7 +897,7 @@ double num;
 			exp_val = 10 * exp_val + c - '0';
 		} while (is_digit (c = s_getchar ()));
 		
-		rval = rval * pow10 (rsign * exp_val);
+		rval = rval * my_pow10 (rsign * exp_val);
 	}
 
 
@@ -1146,7 +1149,8 @@ int quoted_comment;
  
 	for (ptr = e_delim; ptr && *ptr && **ptr; ptr++) {
 		str_ptr = str + str_len - strlen (*ptr);
-		if (! strncmp (str_ptr, *ptr, strlen (*ptr))) {
+		if (str_ptr >= str && 
+		    ! strncmp (str_ptr, *ptr, strlen (*ptr))) {
 #ifdef DEBUG
 			if (do_debug)
 				printf (" found %s.\n", *ptr);
