@@ -1,7 +1,7 @@
 /*
  * Main interpreter module that can handle one language: Algol 60
  *
- * Copyright (C) 1991,1992 Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Copyright (C) 1991,1999 Erik Schoenfelder (schoenfr@web.de)
  *
  * This file is part of NASE A60.
  * 
@@ -83,6 +83,9 @@ static int norun;
 /* don't check the tree (inplicite norun): */
 static int nocheck;
 
+/* use shoertcut evaluation for 'and' and 'or' (default is not): */
+extern int shortcut_eval;
+
 /*
  * look for strict (pedantic) rra60 conformace:
  * (skip whites in input, except in strings)
@@ -98,6 +101,9 @@ int do_memstat;
 /* create c-output: */
 int make_cout;
 
+/* include a60-mkc.inc as a preprocessor directive only */
+int include_file_as_cpp;
+ 
 /* create c-output and compile: */
 int make_bin;
 
@@ -128,7 +134,8 @@ usage ()
 	fprintf (stderr, "\t-i         do not check (parse only)\n");
 	fprintf (stderr, "\t-Wr        warn about runtime decisions\n");
 	fprintf (stderr, "\t-strict    follow strict a60 conventions\n");
-	fprintf (stderr, "\t-c         create c output\n");
+      fprintf (stderr, "\t-c         create c output\n");
+      fprintf (stderr, "\t-I         let cpp include a60-mkc.inc\n");
 	fprintf (stderr, "\t-C         create and compile c output\n");
 	fprintf (stderr, "\t-o <file>  output file; used with -c or -C\n");
 	fprintf (stderr, "\t> <file>   send terminal output to <file>\n");
@@ -165,9 +172,10 @@ char *s;
 static void
 print_header ()
 {
-	fprintf (stderr, " %s\n", VERSION);
+        fprintf (stderr, " %s  http://www.bertnase.de/a60\n",
+                 VERSION);
 	fprintf (stderr,
- " Copyright (C) 1991,1992 Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)\n");
+ " Copyright (C) 1991-2014 Erik Schoenfelder (schoenfr@web.de)\n");
 	fprintf (stderr,
  " The NASE A60 interpreter is free software.  See the file COPYING for\n");
 	fprintf (stderr, " copying permission.\n");
@@ -279,6 +287,11 @@ char *argv[];
 	run_with_xa60 = 0;
 	scan_strict = 0;
 	strict_a60 = 0;
+	include_file_as_cpp = 0;
+#if 0
+	/* not yet, maybe never: arg 's' from main.c: */
+	shortcut_eval = 0;
+#endif
 
 	do_debug = do_memdebug = 0;
 
@@ -286,6 +299,9 @@ char *argv[];
 
 		if((*argv)[0] == '-' && ! (*argv)[2]) {
 			switch((*argv)[1]) {
+                     	case 'I':
+				include_file_as_cpp = 1;
+				break;
 			case 'o':
 				if (argc < 2)
 					usage_err ("incomplete option `-o'");
@@ -322,6 +338,12 @@ char *argv[];
 		"hint: memory statistics not avail.\n");
 #endif /* ! MEMORY_STATISTICS */
 				break;
+#if 0
+			/* not yet, maybe never: */
+			case 's':
+				shortcut_eval = 1;
+				break;
+#endif
 			case 't':
 				trace = 1;
 				break;
