@@ -1,12 +1,12 @@
 #! /bin/sh
 ##
-## make-dist.sh:					june 1991
-## (schoenfr)
+## make-dist.sh:					Jun 1991
+## (schoenfr)						Oct 1999
 ##
 ## use:  make-dist.sh <files for dist>
 ##
 ## Make a distribution tar-file. The file will named like:
-## ``a60-0.16.tar.Z'' and extract into such a directory.
+## ``a60-x.yy.tar.gz'' and extract into such a directory.
 ##
 
 set -e
@@ -19,7 +19,7 @@ fi
 ##
 ## use version number from version.h:
 ##
-ver=`sed -n -e 's/.* v\(.\...\).*$/\1/p' < version.h`
+ver=`sed -n -e 's/.* v\(.\.[^\"]*\).*$/\1/p' < version.h`
 dir="a60-$ver"
 
 echo "Version is $ver"
@@ -36,18 +36,19 @@ files="$*"
 mkdir $dir
 
 echo -n "Copying to $dir ... "
-gtar cf - $files | (cd $dir ; gtar xBf -)
+tar cf - --exclude .svn --exclude micro/Debug $files | (cd $dir ; tar xBf -)
 echo "done."
 
 ##
 ## now $dir is the distribution:
 ##
 
-echo -n "Creating $dir.tar.Z ... "
-gtar czf "$dir".tar.Z $dir
+echo -n "Creating $dir.tar.gz ... "
+tar cvf "$dir".tar $dir
+gzip -v -9 -f "$dir".tar
 echo "done."
 
-ls -l "$dir".tar.Z
+ls -l "$dir".tar*
 
 echo -n "Cleaning up ... "
 rm -rf $dir
