@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1991,1992 Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Copyright (C) 1991,1999 Erik Schoenfelder (schoenfr@web.de)
  *
  * This file is part of NASE A60.
  * 
@@ -19,15 +19,15 @@
  *
  * mkc.c:					oct '90
  *
- * Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Erik Schoenfelder (schoenfr@web.de)
  *
- * The main part of C-code creation. This is at all a simple
+ * The main part of C-code creation. This is a simple
  * mechanism; so ``switches'' are not implemented, the ``own'' concept
  * isn't full implemented at all, mixed call-by-name and call-by-value
  * parameters are handled in C-macros (no local labels; no recursion).
  * Untyped parameters are the hell at all.
  *
- * But for simple programs, this work.
+ * But for simple programs, this works.
  *
  * The options -c and -C are used for C-code generation. With -C the
  * C-compiler defined in config.h is used.
@@ -38,7 +38,6 @@
 #include "tree.h"
 #include "util.h"
 #include "version.h"
-#include "config.h"
 
 
 /* maximum number of array dimensions : */
@@ -228,7 +227,7 @@ mkc_hdr ()
 	 * now copy the ``a60-mkc.inc'' header in:
 	 */
 
-	if (! (in = open_hdr ())) {
+	if (! (in = open_hdr ())  || include_file_as_cpp) {
 		/* include as include: */
 		fprintf (cout, "#include <a60-mkc.inc>\n");
 	}
@@ -449,6 +448,8 @@ SYMTAB *sym;
 			fprintf (cout, "B_INSYMB");
 		else if (! strcmp (name, "inreal"))
 			fprintf (cout, "B_INREAL");
+		else if (! strcmp (name, "ininteger"))
+			fprintf (cout, "B_ININTEGER");
 		else if (! strcmp (name, "print"))
 			fprintf (cout, "B_PRINT");
 		else if (! strcmp (name, "vprint"))
