@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1991,1992 Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Copyright (C) 1991-1998 Erik Schoenfelder (schoenfr@gaertner.de)
  *
  * This file is part of NASE A60.
  * 
@@ -17,18 +17,17 @@
  * along with NASE A60; see the file COPYING.  If not, write to the Free
  * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * version.h					aug '90
+ * version.h					Aug '90
+ *						Jul '14
  *
- * Erik Schoenfelder (schoenfr@ibr.cs.tu-bs.de)
+ * Erik Schoenfelder (schoenfr@web.de)
  */
 
 #ifndef VERSION_H_HOOK
 #define VERSION_H_HOOK
 
 
-#define VERSION		"NASE A60  Version v0.17"
-
-#define PATCHLEVEL	0
+#define VERSION         "NASE A60  Version v0.23a"
 
 
 #endif /* VERSION_H_HOOK */
